Module state_sync_v1::bootstrapper
source · [−]Structs
Creates and bootstraps new state syncs and creates clients for communicating with those state syncs.
Creates and bootstraps new state syncs and creates clients for communicating with those state syncs.