pub enum ResponseLedgerInfo {
VerifiableLedgerInfo(LedgerInfoWithSignatures),
ProgressiveLedgerInfo {
target_li: LedgerInfoWithSignatures,
highest_li: Option<LedgerInfoWithSignatures>,
},
LedgerInfoForWaypoint {
waypoint_li: LedgerInfoWithSignatures,
end_of_epoch_li: Option<LedgerInfoWithSignatures>,
},
}Expand description
The response can carry different LedgerInfo types depending on whether the verification is done via the local trusted validator set or a local waypoint.
Variants
VerifiableLedgerInfo(LedgerInfoWithSignatures)
A typical response carries a LedgerInfo with signatures that should be verified using the
local trusted validator set.
DEPRECATED: VerifiableLedgerInfo is only required for backward compatibility. State
sync avoids sending these response types and instead uses ProgressiveLedgerInfo below.
This message will be removed on the next breaking release: https://github.com/aptos-labs/aptos-core/issues/8013
ProgressiveLedgerInfo
A response to TargetType::HighestAvailable chunk request type.
LedgerInfoForWaypoint
During the initial catchup upon startup the chunks carry LedgerInfo that is verified using the local waypoint.
Implementations