Enums

Constants

Statics

Number of peers that are currently active and upstream. They are the set of nodes a node can make sync requests to

Number of attempts to apply a chunk

Number of failures that occur during the commit flow across consensus, state sync, and mempool

Time it takes for state sync to fully execute a chunk (via executor proxy)

Duration of each run of the event loop.

Highest preference of the networks this node is sending chunk requests to. It is usually 0 if the node’s primary network is healthy, but can be >0 if the node’s primary network is unhealthy/all peers in that network are dead and the node fails over to other networks

Counter of pending network events to State Sync

Time it takes to process a coordinator msg from consensus

Time it takes to process a state sync message from AptosNet

Number of chunk requests sent from a node

Number of chunk responses sent from a node (including FN subscriptions)

Number of transactions in a received chunk response

Number of times a long-poll subscription is successfully delivered

How long it takes to make progress, from requesting a chunk to processing the response and committing the block

Number of times sync request (from consensus) processed

Number of timeouts that occur during sync

Functions